@@ -7,6 +7,8 @@ import abc
 import logging
 import operator
 
+from typing import Optional
+
 try:
     from importlib import metadata  # type: ignore
 except ImportError:
@@ -94,9 +96,8 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
         )
 
     @abc.abstractmethod
-    def get_password(self, service, username):
-        """Get password of the username for the service
-        """
+    def get_password(self, service, username) -> Optional[str]:
+        """Get password of the username for the service"""
         return None
 
     @abc.abstractmethod
@@ -122,7 +123,9 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     # for backward-compatibility, don't require a backend to implement
     #  get_credential
     # @abc.abstractmethod
-    def get_credential(self, service, username):
+    def get_credential(
+        self, service, username
+    ) -> Optional[credentials.SimpleCredential]:
         """Gets the username and password for the service.
         Returns a Credential instance.
 
@@ -151,25 +154,21 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
 
 
 class Crypter:
-    """Base class providing encryption and decryption
-    """
+    """Base class providing encryption and decryption"""
 
     @abc.abstractmethod
     def encrypt(self, value):
-        """Encrypt the value.
-        """
+        """Encrypt the value."""
         pass
 
     @abc.abstractmethod
     def decrypt(self, value):
-        """Decrypt the value.
-        """
+        """Decrypt the value."""
         pass
 
 
 class NullCrypter(Crypter):
-    """A crypter that does nothing
-    """
+    """A crypter that does nothing"""
 
     def encrypt(self, value):
         return value
